@@ -105,6 +105,13 @@ def test_version_compare():
     assert res
     res = utils.version_compare("2.0.27.Final", "*", "*", None, "2.0.29")
     assert res
+    res = utils.version_compare("2.0.27.RELEASE", "*", "2.0.27", None, None)
+    assert res
+
+
+def test_version_compare1():
+    res = utils.version_compare("12.1.0.2.0", "*", "12.1.0.2", None, None)
+    assert res
 
 
 def test_version_compare_go():
